---
hide:
  - navigation
  - toc
---

<style>
.md-content .md-typeset h1 { display: none; }
</style>

<p align="center">
    <img src="https://api.iconify.design/flowbite:paper-plane-solid.svg?color=%231520A6" width="200" height="200">
</p>
<h2 align="center">
    Kamihi
</h2>
<p align="center">
    <em>Python framework for rapid Telegram bot development and management</em>
</p>
<p align="center">
    <a href="https://app.deepsource.com/gh/kamihi-dev/kamihi/" target="_blank"><img alt="DeepSource" title="DeepSource" src="https://app.deepsource.com/gh/kamihi-dev/kamihi.svg/?label=code+coverage&show_trend=false&token=XJwx56oI7k7Bm23vhsstts9q"/></a>
</p>

---

> This project is currently in the early stages of development. Expect frequent changes and updates as we work towards a stable release. Your feedback and contributions are welcome!
